# This file was auto-generated by Fern from our API Definition.

import typing

PostVendorsRootResponseVendorPaymentMethod = typing.Union[
    typing.Literal["Credit Card", "ACH", "Check", "Wire Transfer", "Unknown"], typing.Any
]
