# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .bulk_invoice_operation_response_failed_item import BulkInvoiceOperationResponseFailedItem


class BulkInvoiceOperationResponse(UniversalBaseModel):
    updated: typing.List[int] = pydantic.Field()
    """
    Successfully processed invoice IDs
    """

    failed: typing.List[BulkInvoiceOperationResponseFailedItem] = pydantic.Field()
    """
    Per-invoice errors
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
