# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .get_vendors_id_response import GetVendorsIdResponse
    from .get_vendors_id_response_vendor import GetVendorsIdResponseVendor
    from .get_vendors_id_response_vendor_payment_method import GetVendorsIdResponseVendorPaymentMethod
    from .get_vendors_root_response import GetVendorsRootResponse
    from .get_vendors_root_response_vendors_item import GetVendorsRootResponseVendorsItem
    from .get_vendors_root_response_vendors_item_payment_method import GetVendorsRootResponseVendorsItemPaymentMethod
    from .post_vendors_bulk_create_request_vendors_item import PostVendorsBulkCreateRequestVendorsItem
    from .post_vendors_bulk_create_request_vendors_item_payment_method import (
        PostVendorsBulkCreateRequestVendorsItemPaymentMethod,
    )
    from .post_vendors_bulk_create_response import PostVendorsBulkCreateResponse
    from .post_vendors_bulk_create_response_created_item import PostVendorsBulkCreateResponseCreatedItem
    from .post_vendors_bulk_create_response_created_item_payment_method import (
        PostVendorsBulkCreateResponseCreatedItemPaymentMethod,
    )
    from .post_vendors_bulk_create_response_errors_item import PostVendorsBulkCreateResponseErrorsItem
    from .post_vendors_bulk_create_response_updated_item import PostVendorsBulkCreateResponseUpdatedItem
    from .post_vendors_bulk_create_response_updated_item_payment_method import (
        PostVendorsBulkCreateResponseUpdatedItemPaymentMethod,
    )
    from .post_vendors_root_request_payment_method import PostVendorsRootRequestPaymentMethod
    from .post_vendors_root_response import PostVendorsRootResponse
    from .post_vendors_root_response_vendor import PostVendorsRootResponseVendor
    from .post_vendors_root_response_vendor_payment_method import PostVendorsRootResponseVendorPaymentMethod
_dynamic_imports: typing.Dict[str, str] = {
    "GetVendorsIdResponse": ".get_vendors_id_response",
    "GetVendorsIdResponseVendor": ".get_vendors_id_response_vendor",
    "GetVendorsIdResponseVendorPaymentMethod": ".get_vendors_id_response_vendor_payment_method",
    "GetVendorsRootResponse": ".get_vendors_root_response",
    "GetVendorsRootResponseVendorsItem": ".get_vendors_root_response_vendors_item",
    "GetVendorsRootResponseVendorsItemPaymentMethod": ".get_vendors_root_response_vendors_item_payment_method",
    "PostVendorsBulkCreateRequestVendorsItem": ".post_vendors_bulk_create_request_vendors_item",
    "PostVendorsBulkCreateRequestVendorsItemPaymentMethod": ".post_vendors_bulk_create_request_vendors_item_payment_method",
    "PostVendorsBulkCreateResponse": ".post_vendors_bulk_create_response",
    "PostVendorsBulkCreateResponseCreatedItem": ".post_vendors_bulk_create_response_created_item",
    "PostVendorsBulkCreateResponseCreatedItemPaymentMethod": ".post_vendors_bulk_create_response_created_item_payment_method",
    "PostVendorsBulkCreateResponseErrorsItem": ".post_vendors_bulk_create_response_errors_item",
    "PostVendorsBulkCreateResponseUpdatedItem": ".post_vendors_bulk_create_response_updated_item",
    "PostVendorsBulkCreateResponseUpdatedItemPaymentMethod": ".post_vendors_bulk_create_response_updated_item_payment_method",
    "PostVendorsRootRequestPaymentMethod": ".post_vendors_root_request_payment_method",
    "PostVendorsRootResponse": ".post_vendors_root_response",
    "PostVendorsRootResponseVendor": ".post_vendors_root_response_vendor",
    "PostVendorsRootResponseVendorPaymentMethod": ".post_vendors_root_response_vendor_payment_method",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "GetVendorsIdResponse",
    "GetVendorsIdResponseVendor",
    "GetVendorsIdResponseVendorPaymentMethod",
    "GetVendorsRootResponse",
    "GetVendorsRootResponseVendorsItem",
    "GetVendorsRootResponseVendorsItemPaymentMethod",
    "PostVendorsBulkCreateRequestVendorsItem",
    "PostVendorsBulkCreateRequestVendorsItemPaymentMethod",
    "PostVendorsBulkCreateResponse",
    "PostVendorsBulkCreateResponseCreatedItem",
    "PostVendorsBulkCreateResponseCreatedItemPaymentMethod",
    "PostVendorsBulkCreateResponseErrorsItem",
    "PostVendorsBulkCreateResponseUpdatedItem",
    "PostVendorsBulkCreateResponseUpdatedItemPaymentMethod",
    "PostVendorsRootRequestPaymentMethod",
    "PostVendorsRootResponse",
    "PostVendorsRootResponseVendor",
    "PostVendorsRootResponseVendorPaymentMethod",
]
