# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .receipt_bulk_upsert_request_receipts_item_items_item import ReceiptBulkUpsertRequestReceiptsItemItemsItem


class ReceiptBulkUpsertRequestReceiptsItem(UniversalBaseModel):
    purchase_order_id: str
    external_id: typing.Optional[str] = None
    number: str
    date: str
    total_amount: float
    invoice_number_ref: typing.Optional[str] = pydantic.Field(default=None)
    """
    Invoice reference number
    """

    note: typing.Optional[str] = None
    items: typing.List[ReceiptBulkUpsertRequestReceiptsItemItemsItem]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
